﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;

namespace ThemingDemo
{
	public class MainViewModel : INotifyPropertyChanged
	{
		private ThemeData _selectedTheme;
		
		public event PropertyChangedEventHandler PropertyChanged;

		public ObservableCollection<ThemeData> Themes
		{
			get;
			private set;
		}

		public ThemeData SelectedTheme
		{
			get
			{
				return _selectedTheme;
			}
			set
			{
				if (_selectedTheme != value)
				{
					_selectedTheme = value;

					ChangeTheme();

					RaisePropertyChanged("SelectedTheme");
				}
			}
		}

		public ICommand ChangeThemeCommand
		{
			get;
			private set;
		}

		public MainViewModel()
		{
			ChangeThemeCommand = new ChangeThemeCommand();

			Themes = new ObservableCollection<ThemeData>();
			
			Themes.Add(new ThemeData()
			{
				Name = "Jet Pack",
				Description = "Theme pack based on the Jet Pack styles",
				Path = "/JetPackTheme;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "Cosmopolitan",
				Description = "Theme pack based on the Cosmopolitan styles",
				Path = "/CosmopolitanTheme;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "Windows 7",
				Description = "Theme pack based on the Windows 7 styles",
				Path = "/Windows7Theme;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "Accent Color",
				Description = "Theme pack based on the Accent Color styles",
				Path = "/AccentColorTheme;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "Bubble Creme",
				Description = "Theme pack included in the Silverlight Toolkit",
				Path = "/System.Windows.Controls.Theming.BubbleCreme;component/Theme.xaml"
			});

			// black text on black background... :-/
			//Themes.Add(new ThemeData()
			//{
			//    Name = "Bureau Black",
			//    Description = "Theme pack included in the Silverlight Toolkit",
			//    Path = "/System.Windows.Controls.Theming.BureauBlack;component/Theme.xaml"
			//});

			Themes.Add(new ThemeData()
			{
				Name = "Bureau Blue",
				Description = "Theme pack included in the Silverlight Toolkit",
				Path = "/System.Windows.Controls.Theming.BureauBlue;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "Expression Dark",
				Description = "Theme pack included in the Silverlight Toolkit",
				Path = "/System.Windows.Controls.Theming.ExpressionDark;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "Expression Light",
				Description = "Theme pack included in the Silverlight Toolkit",
				Path = "/System.Windows.Controls.Theming.ExpressionLight;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "Rainier Orange",
				Description = "Theme pack included in the Silverlight Toolkit",
				Path = "/System.Windows.Controls.Theming.RainierOrange;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "Rainier Purple",
				Description = "Theme pack included in the Silverlight Toolkit",
				Path = "/System.Windows.Controls.Theming.RainierPurple;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "Shiny Blue",
				Description = "Theme pack included in the Silverlight Toolkit",
				Path = "/System.Windows.Controls.Theming.ShinyBlue;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "Shiny Red",
				Description = "Theme pack included in the Silverlight Toolkit",
				Path = "/System.Windows.Controls.Theming.ShinyRed;component/Theme.xaml"
			});

			// the system colors theme breaks the background settings of other themes,
			// see: http://silverlight.codeplex.com/workitem/6550
			//Themes.Add(new ThemeData()
			//{
			//    Name = "System Colors",
			//    Path = "/System.Windows.Controls.Theming.SystemColors;component/Theme.xaml"
			//});

			Themes.Add(new ThemeData()
			{
				Name = "Twilight Blue",
				Description = "Theme pack included in the Silverlight Toolkit",
				Path = "/System.Windows.Controls.Theming.TwilightBlue;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "Whistler Blue",
				Description = "Theme pack included in the Silverlight Toolkit",
				Path = "/System.Windows.Controls.Theming.WhistlerBlue;component/Theme.xaml"
			});

			Themes.Add(new ThemeData()
			{
				Name = "[No theme]",
				Description = "Default Silverlight look (no theme applied)",
				Path = null
			});

			SelectedTheme = Themes[0];
		}
		
		private void ChangeTheme()
		{
			ChangeThemeCommand.Execute(SelectedTheme);
		}

		private void RaisePropertyChanged(string propertyName)
		{
			if (PropertyChanged != null)
			{
				PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
			}
		}
	}
}
